use super::character::{create_character, Character};
use super::class::Class;
use super::equipment::{Armor, WeaponType};
use super::stats::StatBlock;

/*
 * Bob has chosen to play a knight who is also an [NPC].
 * He has chosen to make a knight who is strong and dexterous.
 * He has also decided that his knight is not charismatic, but rather athletic.
 */
pub fn get_bob() -> Character {
    create_character(
        "Bob".to_owned(),
        Class::Knight,
        Class::NPC,
        StatBlock::from((1, 1, 0, 0, 0, 0, 0, 0)),
        StatBlock::from((0, 0, 2, 0, 0, 0, 0, -2)),
        Armor::Medium,
        WeaponType::BladedWeapon.create_weapon("Longsword".to_owned()),
    )
}

/*
 * Drub is a goblin.
 */
pub fn get_drub() -> Character {
    let mut drub = create_character(
        String::from("Drub"),
        Class::NPC,
        Class::NPC,
        StatBlock::from((2, 3, 2, 0, 1, 0, -3, -2)),
        StatBlock::default(),
        Armor::Light,
        WeaponType::SimpleWeapon.create_weapon(String::from("Knife")),
    );

    drub.proficiencies.simple_weapons = true;
    drub.proficiencies.light_armor = true;

    return drub
}

#[cfg(test)]
mod premade_tests {

    use super::{get_bob, get_drub};

    #[test]
    fn print_bob() {
        let bob = get_bob();

        println!("{}", bob);
    }

    #[test]
    fn print_drub() {
        let drub = get_drub();

        println!("{}", drub);
    }
}
